@@ -24,16 +24,13 @@
 # ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 # SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
-
 import inspect
-
 import pecan
 import pecan.rest
 import pecan.routing
+from designate.openstack.common import log as logging
 
-from designate import exceptions
-from designate.central import rpcapi as central_rpcapi
+LOG = logging.getLogger(__name__)
 
 
 class RestController(pecan.rest.RestController):
@@ -44,114 +41,90 @@ class RestController(pecan.rest.RestController):
     Ideally, we get these additions merged upstream.
     """
 
-    # default sort_keys.  The Controllers can override this.
-    SORT_KEYS = ['created_at', 'id']
-
-    @property
-    def central_api(self):
-        return central_rpcapi.CentralAPI.get_instance()
-
-    def _apply_filter_params(self, params, accepted_filters, criterion):
-        invalid = []
-        for k in params:
-            if k in accepted_filters:
-                criterion[k] = params[k].replace("*", "%")
-            else:
-                invalid.append(k)
-        if invalid:
-            raise exceptions.BadRequest(
-                'Invalid filters %s' % ', '.join(invalid))
-        else:
-            return criterion
-
-    def _handle_post(self, method, remainder, request=None):
-        """
+    def _handle_post(self, method, remainder):
+        '''
         Routes ``POST`` actions to the appropriate controller.
-        """
+        '''
         # route to a post_all or get if no additional parts are available
         if not remainder or remainder == ['']:
             controller = self._find_controller('post_all', 'post')
             if controller:
                 return controller, []
-            pecan.abort(405)
+            pecan.abort(404)
 
         controller = getattr(self, remainder[0], None)
         if controller and not inspect.ismethod(controller):
-            return pecan.routing.lookup_controller(controller, remainder[1:],
-                                                   request=request)
+            return pecan.routing.lookup_controller(controller, remainder[1:])
 
         # finally, check for the regular post_one/post requests
         controller = self._find_controller('post_one', 'post')
         if controller:
             return controller, remainder
 
-        pecan.abort(405)
+        pecan.abort(404)
 
-    def _handle_patch(self, method, remainder, request=None):
-        """
+    def _handle_patch(self, method, remainder):
+        '''
         Routes ``PATCH`` actions to the appropriate controller.
-        """
+        '''
         # route to a patch_all or get if no additional parts are available
         if not remainder or remainder == ['']:
             controller = self._find_controller('patch_all', 'patch')
             if controller:
                 return controller, []
-            pecan.abort(405)
+            pecan.abort(404)
 
         controller = getattr(self, remainder[0], None)
         if controller and not inspect.ismethod(controller):
-            return pecan.routing.lookup_controller(controller, remainder[1:],
-                                                   request=request)
+            return pecan.routing.lookup_controller(controller, remainder[1:])
 
         # finally, check for the regular patch_one/patch requests
         controller = self._find_controller('patch_one', 'patch')
         if controller:
             return controller, remainder
 
-        pecan.abort(405)
+        pecan.abort(404)
 
-    def _handle_put(self, method, remainder, request=None):
-        """
+    def _handle_put(self, method, remainder):
+        '''
         Routes ``PUT`` actions to the appropriate controller.
-        """
+        '''
         # route to a put_all or get if no additional parts are available
         if not remainder or remainder == ['']:
             controller = self._find_controller('put_all', 'put')
             if controller:
                 return controller, []
-            pecan.abort(405)
+            pecan.abort(404)
 
         controller = getattr(self, remainder[0], None)
         if controller and not inspect.ismethod(controller):
-            return pecan.routing.lookup_controller(controller, remainder[1:],
-                                                   request=request)
+            return pecan.routing.lookup_controller(controller, remainder[1:])
 
         # finally, check for the regular put_one/put requests
         controller = self._find_controller('put_one', 'put')
         if controller:
             return controller, remainder
 
-        pecan.abort(405)
+        pecan.abort(404)
 
-    def _handle_delete(self, method, remainder, request=None):
-        """
+    def _handle_delete(self, method, remainder):
+        '''
         Routes ``DELETE`` actions to the appropriate controller.
-        """
+        '''
         # route to a delete_all or get if no additional parts are available
         if not remainder or remainder == ['']:
             controller = self._find_controller('delete_all', 'delete')
             if controller:
                 return controller, []
-            pecan.abort(405)
+            pecan.abort(404)
 
         controller = getattr(self, remainder[0], None)
         if controller and not inspect.ismethod(controller):
-            return pecan.routing.lookup_controller(controller, remainder[1:],
-                                                   request=request)
+            return pecan.routing.lookup_controller(controller, remainder[1:])
 
         # finally, check for the regular delete_one/delete requests
         controller = self._find_controller('delete_one', 'delete')
         if controller:
             return controller, remainder
 
-        pecan.abort(405)
+        pecan.abort(404)
