@@ -1,6 +1,6 @@
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
-# Author: Kiall Mac Innes <kiall@hpe.com>
+# Author: Kiall Mac Innes <kiall@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -14,17 +14,25 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import datetime
-
 import jsonschema
-from jsonschema import _utils
+
+try:
+    # JSONSchema 2+
+    from jsonschema import _utils
+    ensure_list = _utils.ensure_list
+    types_msg = _utils.types_msg
+except ImportError:
+    # JSONSchema 1.3
+    ensure_list = jsonschema._list
+    types_msg = jsonschema._types_msg
 
 
 def type_draft3(validator, types, instance, schema):
-    types = _utils.ensure_list(types)
+    types = ensure_list(types)
 
     # NOTE(kiall): A datetime object is not a string, but is still valid.
-    if ('format' in schema and schema['format'] == 'date-time' and
-            isinstance(instance, datetime.datetime)):
+    if ('format' in schema and schema['format'] == 'date-time'
+            and isinstance(instance, datetime.datetime)):
         return
 
     all_errors = []
@@ -41,7 +49,7 @@ def type_draft3(validator, types, instance, schema):
                 return
     else:
         yield jsonschema.ValidationError(
-            _utils.types_msg(instance, types), context=all_errors,
+            types_msg(instance, types), context=all_errors,
         )
 
 
@@ -68,12 +76,12 @@ def oneOf_draft3(validator, oneOf, instance, schema):
 
 
 def type_draft4(validator, types, instance, schema):
-    types = _utils.ensure_list(types)
+    types = ensure_list(types)
 
     # NOTE(kiall): A datetime object is not a string, but is still valid.
-    if ('format' in schema and schema['format'] == 'date-time' and
-            isinstance(instance, datetime.datetime)):
+    if ('format' in schema and schema['format'] == 'date-time'
+            and isinstance(instance, datetime.datetime)):
         return
 
     if not any(validator.is_type(instance, type) for type in types):
-        yield jsonschema.ValidationError(_utils.types_msg(instance, types))
+        yield jsonschema.ValidationError(types_msg(instance, types))
