@@ -17,4 +17,4 @@ from designate.tests import TestCase
 
 
 class ApiTestCase(TestCase):
-    pass
+    __test__ = False
